==============
 pytest-REANA
==============

.. image:: https://img.shields.io/pypi/pyversions/pytest-reana.svg
      :target: https://pypi.org/pypi/pytest-reana

.. image:: https://img.shields.io/travis/reanahub/pytest-reana.svg
      :target: https://travis-ci.org/reanahub/pytest-reana

.. image:: https://readthedocs.org/projects/docs/badge/?version=latest
      :target: https://pytest-reana.readthedocs.io/en/latest/?badge=latest

.. image:: https://img.shields.io/coveralls/reanahub/pytest-reana.svg
      :target: https://coveralls.io/r/reanahub/pytest-reana

.. image:: https://badges.gitter.im/Join%20Chat.svg
      :target: https://gitter.im/reanahub/reana?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge

.. image:: https://img.shields.io/github/license/reanahub/pytest-reana.svg
      :target: https://github.com/reanahub/pytest-reana/blob/master/LICENSE

About
-----

pytest-REANA is a component of the `REANA <http://www.reana.io/>`_ reusable and
reproducible research data analysis platform. It provides pytest fixtures and
test utilities.

Features
--------

- pytest fixtures
- mocking OpenAPI client with request format validation
- mocking Advanced Message Queuing Protocol consumers and producers
- mocking Celery tasks
- mocking file system workspace access
- mocking database access
- includes sample workspace directory

Useful links
------------

- `documentation <https://pytest-reana.readthedocs.io/>`_
- `releases <https://github.com/reanahub/pytest-reana/releases>`_
- `known issues <https://github.com/reanahub/pytest-reana/issues>`_
- `source code <https://github.com/reanahub/pytest-reana>`_

For more information about the REANA reusable analysis platform, please see the
`REANA project <http://www.reana.io>`_ home page and the general `REANA
documentation <http://reana.readthedocs.io/>`_ pages.
